create_begin_block

Function create_begin_block 

fn create_begin_block(
    program_start: Option<Address>,
    empty_program: bool,
) -> Result<Vec<Unsigned36Bit>, AssemblerFailure>
Assemble a pair of instructions to go into registers 0o27 and 0o28, immediately after the reader leader. This instruction calls the user’s program (which begins at the address specified by the PUNCH meta command).