fn create_tape_block(
address: Address,
code: &[Unsigned36Bit],
last: bool,
) -> Result<Vec<Unsigned36Bit>, AssemblerFailure>Expand description
Create (and return) a block of data ready to be punched to tape such that the standard reader leader can load it.
See ../readerleader.rs for documentation on the format of a block.